Class: Axlsx::Line3DChart
- Inherits:
-
LineChart
- Object
- LineChart
- Axlsx::Line3DChart
- Defined in:
- lib/axlsx/drawing/line_3D_chart.rb
Overview
The Line3DChart is a three dimensional line chart (who would have guessed?) that you can add to your worksheet.
Constant Summary collapse
- GAP_AMOUNT_PERCENT =
validation regex for gap amount percent
/0*(([0-9])|([1-9][0-9])|([1-4][0-9][0-9])|500)%/.freeze
Instance Attribute Summary collapse
-
#gap_depth ⇒ String
(also: #gapDepth)
space between bar or column clusters, as a percentage of the bar or column width.
Instance Method Summary collapse
-
#initialize(frame, options = {}) ⇒ Line3DChart
constructor
Creates a new line chart object.
-
#ser_axis ⇒ Axis
(also: #serAxis)
the category axis.
-
#to_xml_string(str = +'')) ⇒ String
Serializes the object.
Constructor Details
#initialize(frame, options = {}) ⇒ Line3DChart
Creates a new line chart object
43 44 45 46 47 48 |
# File 'lib/axlsx/drawing/line_3D_chart.rb', line 43 def initialize(frame, = {}) @gap_depth = nil @view_3D = View3D.new({ r_ang_ax: 1 }.merge()) super axes.add_axis :ser_axis, SerAxis end |
Instance Attribute Details
#gap_depth ⇒ String Also known as: gapDepth
space between bar or column clusters, as a percentage of the bar or column width.
25 26 27 |
# File 'lib/axlsx/drawing/line_3D_chart.rb', line 25 def gap_depth @gap_depth end |
Instance Method Details
#ser_axis ⇒ Axis Also known as: serAxis
the category axis
33 34 35 |
# File 'lib/axlsx/drawing/line_3D_chart.rb', line 33 def ser_axis axes[:ser_axis] end |
#to_xml_string(str = +'')) ⇒ String
Serializes the object
60 61 62 63 64 |
# File 'lib/axlsx/drawing/line_3D_chart.rb', line 60 def to_xml_string(str = +'') super do str << '<c:gapDepth val="' << @gap_depth.to_s << '"/>' unless @gap_depth.nil? end end |